<?php
/* $Id: chinese_simplified-gb2312.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */

/**
 * Last translation by: Funda Wang <fundawang@en2china.com>
 * update by Simon <simon@venustech.com.cn>
 */

$charset = 'gb2312';
$text_dir = 'ltr';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('ֽ', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$mysql_5_1_doc_lang = 'zh';

$day_of_week = array('', 'һ', 'ܶ', '', '', '', '');
$month = array('һ', '', '', '', '', '', '', '', '', 'ʮ', 'ʮһ', 'ʮ');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%Y  %m  %d  %H:%M';

$timespanfmt = '%s  %s Сʱ%s  %s ';

$strAbortedClients = 'ֹ';
$strAccessDenied = 'ʱܾ';
$strAccessDeniedExplanation = 'phpMyAdmin ͼӵ MySQL ܾӡӦü config.inc.php еû룬ȷЩϢ MySQL ĹԱϢһ¡';
$strAction = '';
$strAddAutoIncrement = ' AUTO_INCREMENT ֵ';
$strAddConstraints = 'ǿ';
$strAddDeleteColumn = '/ɾֶ';
$strAddDeleteRow = '/ɾ';
$strAddFields = ' %s ֶ';
$strAddHeaderComment = 'ڱһƵע (\\n и)';
$strAddIntoComments = 'ӽע';
$strAddNewField = 'ֶ';
$strAddPrivilegesOnDb = 'ݿȨ';
$strAddPrivilegesOnTbl = 'бȨ';
$strAddSearchConditions = '(where)';
$strAddToIndex = 'ӵ %s ';
$strAddUserMessage = 'һû';
$strAddUser = 'û';
$strAdministration = '';
$strAffectedRows = 'Ӱ';
$strAfterInsertBack = '˵һҳ';
$strAfterInsertNewInsert = 'µһ';
$strAfterInsertNext = '༭һ';
$strAfterInsertSame = 'һҳ';
$strAfter = ' %s ֮';
$strAll = 'ȫ';
$strAllTableSameWidth = 'ͬʾб?';
$strAlterOrderBy = 'ı˳';
$strAnalyzeTable = '';
$strAnd = '';
$strAnIndex = 'Ѿӵ %s';
$strAny = '';
$strAnyHost = '';
$strAnyUser = 'û';
$strApproximateCount = 'ܽӽ. ο FAQ 3.11';
$strAPrimaryKey = 'Ѿӵ %s';
$strArabic = '';
$strArmenian = '';
$strAscending = '';
$strAtBeginningOfTable = 'ڱͷ';
$strAtEndOfTable = 'ڱβ';
$strAttr = '';
$strAutodetect = 'Զ';
$strAutomaticLayout = 'Զøʽ';

$strBack = '';
$strBaltic = '';
$strBeginCut = 'ʼ';
$strBeginRaw = 'ʼԭ';
$strBinary = '';
$strBinaryDoNotEdit = ' - ޷༭';
$strBinaryLog = '־';
$strBinLogEventType = '¼';
$strBinLogInfo = 'Ϣ';
$strBinLogName = '־ļ';
$strBinLogOriginalPosition = 'ʼλ';
$strBinLogPosition = 'λ';
$strBinLogServerId = 'ID';
$strBookmarkAllUsers = 'ÿûԷǩ';
$strBookmarkDeleted = 'ǩѾɾ';
$strBookmarkLabel = 'ǩ';
$strBookmarkQuery = 'Ѽǩ SQL ѯ';
$strBookmarkThis = ' SQL ѯΪǩ';
$strBookmarkView = 'ֻ鿴';
$strBrowse = '';
$strBrowseForeignValues = 'صֵ';
$strBulgarian = '';
$strBzError = 'phpMyAdmin ޷ѹת棬ԭǴ˰汾 php е Bz2 ģ𻵡ǿƽ phpMyAdmin ļе <code>$cfg[\'BZipDump\']</code> Ϊ <code>FALSE</code>ʹ Bz2 ѹܣ php İ汾ο php 󱨸 %s';
$strBzip = 'bzip ѹ';

$strCalendar = '';
$strCannotLogin = '޷ MySQL ';
$strCantLoadRecodeIconv = '޷ iconv ַ߽תرչ php ʹЩչ phpMyAdmin нַתܡ';
$strCantLoad = '޷ %s չ<br /> PHP ';
$strCantRenameIdxToPrimary = '޷Ϊ PRIMARY';
$strCantUseRecodeIconv = 'չʱ iconvlibiconv  recode_string ޷ʹá php á';
$strCardinality = '';
$strCaseInsensitive = 'ִСд';
$strCaseSensitive = 'ִСд';
$strCentralEuropean = 'ŷ';
$strChange = '';
$strChangeCopyModeCopy = '... û';
$strChangeCopyModeDeleteAndReload = ' ... ûɾûȻȨޡ';
$strChangeCopyModeJustDelete = ' ... ûɾû';
$strChangeCopyModeRevoke = ' ... ջؾûмȨޣȻɾû';
$strChangeCopyMode = 'ͬȨ޵û ...';
$strChangeCopyUser = 'ĵ¼Ϣ/û';
$strChangeDisplay = 'ѡҪʾֶ';
$strChangePassword = '';
$strCharset = 'ַ';
$strCharsetOfFile = 'ļַ';
$strCharsets = 'ַ';
$strCharsetsAndCollations = 'ַ';
$strCheckAll = 'ȫѡ';
$strCheckOverhead = '׼';
$strCheckPrivs = 'Ȩ';
$strCheckPrivsLong = 'ݿ⡰%sȨޡ';
$strCheckTable = '';
$strChoosePage = 'ѡҪ༭ҳ';
$strColComFeat = 'ʾע';
$strCollation = '';
$strColumnNames = '';
$strColumnPrivileges = 'ָȨ';
$strCommand = '';
$strCommentsForTable = 'ע';
$strComments = 'ע';
$strCompatibleHashing = 'MySQL&nbsp;4.0 ';
$strCompleteInserts = '';
$strCompression = 'ѹ';
$strConfigFileError = 'phpMyAdmin ޷ȡļ<br />Ϊ php ﷨ php δҵĵ<br />ֱʹӵļȻȡյ php ʾͨĴΪĳ©Żֺš<br />һհҳûκ⡣';
$strConfigureTableCoord = 'ñ %s ';
$strConnectionError = '޷ӣǷá';
$strConnections = '';
$strConstraintsForDumped = 'Ƶı';
$strConstraintsForTable = 'Ʊ';
$strCookiesRequired = 'Cookies òܵ롣';
$strCopyDatabaseOK = 'ݿ %sѾƵ%s';
$strCopyTable = 'Ƶ(ݿ<b>.</b>)';
$strCopyTableOK = ' %s ѾɹΪ %s';
$strCopyTableSameNames = '޷Ϊͬƣ';
$strCouldNotKill = 'phpMyAdmin ޷ɱ߳ %sܸ߳Ѿرա';
$strCreate = '';
$strCreateIndex = 'ڵ %s д';
$strCreateIndexTopic = '';
$strCreateNewDatabase = 'һµݿ';
$strCreateNewTable = 'ݿ %s дһ±';
$strCreatePage = 'ҳ';
$strCreatePdfFeat = ' PDF';
$strCreationDates = '//ڼ';
$strCriteria = '';
$strCroatian = '޵';
$strCSVOptions = 'CSV ѡ';
$strCyrillic = '';
$strCzech = 'ݿ';
$strCzechSlovak = 'ݿ˹工';

$strDanish = '';
$strData = '';
$strDatabase = 'ݿ';
$strDatabaseEmpty = 'ݿǿգ';
$strDatabaseExportOptions = 'ݿ⵼ѡ';
$strDatabaseHasBeenDropped = 'ݿ %s ѱɾ';
$strDatabaseNoTable = 'ݿûб';
$strDatabases = 'ݿ';
$strDatabasesDropped = 'Ѿɹɾ %s ݿ⡣';
$strDatabasesStats = 'ݿͳ';
$strDatabasesStatsDisable = 'ͳ';
$strDatabasesStatsEnable = 'ͳ';
$strDatabasesStatsHeavyTraffic = 'ע⣺ڴݿͳƿܵվ MySQL ֮';
$strDataDict = 'ֵ';
$strDataOnly = 'ֻ';
$strDBComment = 'ݿעͣ';
$strDBCopy = 'ݿ⵽';
$strDbPrivileges = 'ݿָȨ';
$strDBRename = 'ݿΪ ';
$strDbSpecific = 'ݿָ';
$strDefault = 'Ĭ';
$strDefaultValueHelp = 'Ĭֵֻ뵥ֵҪӷб߻ţô˸ʽa';
$strDefragment = 'Ƭ';
$strDelayedInserts = 'ʱ';
$strDelete = 'ɾ';
$strDeleteAndFlushDescr = 'һɾ¶ȡȨһʱ䡣';
$strDeleteAndFlush = 'ɾû¶ȡȨޡ';
$strDeleted = 'Ѿɾ';
$strDeletedRows = 'ɾ';
$strDeleting = 'ɾ %s';
$strDelOld = 'ǰҳõıˡǷҪɾЩ?';
$strDescending = 'ݼ';
$strDescription = '';
$strDictionary = 'ֵ';
$strDisabled = 'ѽ';
$strDisableForeignChecks = 'ֹѡص';
$strDisplayFeat = 'ʾ';
$strDisplayOrder = 'ʾ˳';
$strDisplayPDF = 'ʾ PDF ';
$strDoAQuery = 'ִСѯ(ͨ%)';
$strDocu = 'ĵ';
$strDoYouReally = 'Ҫ';
$strDrop = 'ɾ';
$strDropDatabaseStrongWarning = 'Ҫɾһݿ⣡';
$strDropUsersDb = 'ɾûͬݿ⡣';
$strDumpingData = 'е';
$strDumpSaved = 'תѾ浽ļ %s ˡ';
$strDumpXRows = 'ת %s УӼ¼ #%s ʼ';
$strDynamic = '̬';

$strEdit = '༭';
$strEditPDFPages = '༭ PDF ҳ';
$strEditPrivileges = '༭Ȩ';
$strEffective = 'Ч';
$strEmpty = '';
$strEmptyResultSet = 'MySQL صĲѯΪ()';
$strEnabled = '';
$strEncloseInTransaction = 'зװ';
$strEnd = '';
$strEndCut = '';
$strEndRaw = 'ԭ';
$strEnglish = 'Ӣ';
$strEnglishPrivileges = ' ע⣺MySQL ȨƻӢʾ ';
$strError = '';
$strEscapeWildcards = 'ͨ _  % Ӧȷؼ \ ';
$strEstonian = 'ɳ';
$strExcelEdition = 'Excel 汾';
$strExcelOptions = 'Excel ѡ';
$strExecuteBookmarked = 'ִǩеĲѯ';
$strExplain = ' SQL';
$strExport = '';
$strExtendedInserts = 'չ';
$strExtra = '';

$strFailedAttempts = 'ʧ';
$strField = 'ֶ';
$strFieldHasBeenDropped = 'ֶ %s ѱɾ';
$strFields = 'ֶ';
$strFieldsEmpty = ' ֶǿյģ';
$strFieldsEnclosedBy = 'ֶεַ';
$strFieldsEscapedBy = 'תֶεַ';
$strFieldsTerminatedBy = 'ֶָεַ';
$strFileAlreadyExists = 'ļ %s Ѿڷϣļѡиѡ';
$strFileCouldNotBeRead = 'ļ޷ȡ';
$strFileNameTemplate = 'ļģ';
$strFileNameTemplateRemember = 'סģ';
$strFixed = '̶';
$strFlushPrivilegesNote = 'ע⣺phpMyAdmin ֱ MySQL ȨޱȡûȨޡûֶıݽʹõûȨ졣£Ӧڼǰ%sȨ%s';
$strFlushTable = 'ǿƸϱ("FLUSH")';
$strFormat = 'ʽ';
$strFormEmpty = 'ȱֵ';
$strFullText = '';
$strFunction = '';

$strGenBy = '';
$strGeneralRelationFeat = 'һϵ';
$strGenTime = '';
$strGeorgian = '';
$strGerman = '';
$strGlobal = 'ȫ';
$strGlobalPrivileges = 'ȫȨ';
$strGlobalValue = 'ȫֵ';
$strGo = 'ִ';
$strGrantOption = 'Ȩ';
$strGreek = 'ϣ';
$strGzip = 'gzip ѹ';

$strHasBeenAltered = 'Ѿ޸ġ';
$strHasBeenCreated = 'Ѿ';
$strHaveToShow = 'Ҫѡʾһ';
$strHebrew = 'ϣ';
$strHexForBinary = 'ʹʮʾ';
$strHome = 'Ŀ¼';
$strHomepageOfficial = 'phpMyAdmin ٷվ';
$strHost = '';
$strHostEmpty = 'ǿյģ';
$strHungarian = '';

$strIcelandic = '';
$strId = 'ID'; // use eng
$strIdxFulltext = 'ȫ';
$strIgnore = '';
$strIgnoreInserts = 'Բ';
$strImportFiles = 'ļ';
$strIndex = '';
$strIndexes = '';
$strIndexHasBeenDropped = ' %s ѱɾ';
$strIndexName = 'ƣ';
$strIndexType = 'ͣ';
$strIndexWarningMultiple = '棺һ %s  ֶ `%s`';
$strIndexWarningPrimary = '棺PRIMARYINDEXӦͬʱֶ `%s` ';
$strIndexWarningTable = '棺ݱ `%s`';
$strIndexWarningUnique = '棺ΨһUNIQUEINDEXӦͬʱֶ `%s` ';
$strInnodbStat = 'InnoDB ״̬';
$strInsecureMySQL = 'ļе趨 MySQL ĬȨ˻Ӧ(û root) MySQL ʹĬֵеȻû⣬ĻֵĿԻܴӦȲȫ©';
$strInsert = '';
$strInsertAsNewRow = 'в';
$strInsertedRowId = ' id';
$strInsertedRows = '';
$strInternalNotNecessary = ' * ҲInnoDBеʱڲҪ';
$strInternalRelations = 'ϵ';
$strInUse = 'ʹ';

$strJapanese = '';
$strJumpToDB = 'ݿ⡰%s';
$strJustDeleteDescr = 'ɾûȻһݿ⣬ֱȨޡ';
$strJustDelete = 'ֻȨݿɾû';

$strKeepPass = '벻Ҫ';
$strKeyname = '';
$strKill = 'Kill'; //should expressed in English
$strKorean = '';

$strLandscape = '';
$strLatexCaption = 'ı';
$strLatexContent = '__TABLE__ ';
$strLatexContinued = '()';
$strLatexContinuedCaption = 'ıı';
$strLatexIncludeCaption = 'ı';
$strLatexLabel = 'ؼǩ';
$strLaTeX = 'LaTeX';  // use eng
$strLaTeXOptions = 'LaTeX ѡ';
$strLatexStructure = '__TABLE__ Ľṹ';
$strLatvian = 'ά';
$strLengthSet = '/ֵ*';
$strLimitNumRows = 'ÿҳ';
$strLinesTerminatedBy = 'ַֹ';
$strLinkNotFound = 'Ҳ';
$strLinksTo = 'ӵ';
$strLithuanian = '';
$strLocalhost = '';
$strLocationTextfile = 'ıļλ';
$strLogin = '';
$strLoginInformation = 'Ϣ';
$strLogout = 'ǳ';
$strLogPassword = '룺';
$strLogServer = '';
$strLogUsername = 'ƣ';

$strMaximumSize = 'ƣ%s %s';
$strMbExtensionMissing = 'ûз PHP չmbstring ǰϵͳʹÿַû mbstring չ phpMyAdmin ȷʶַܲϵĽ.';
$strMbOverloadWarning = '棺PHPļ mbstring.func_overload. ѡphpMyAdminݣܻᵼһЩݱض!';
$strMIME_available_mime = 'õ MIME ';
$strMIME_available_transform = 'õı任';
$strMIME_description = '';
$strMIME_MIMEtype = 'MIME ';
$strMIME_nodescription = '˱任޿õ<br />ϸѯ %s ߡ';
$strMIME_transformation_note = 'Ҫÿñ任ѡ嵥Ӧ MIME ͱ任뵥%s任%s';
$strMIME_transformation_options_note = 'ʹô˸ʽ任ѡֵ\'a\', 100, b,\'c\'...<br />Ҫֵ뷴б(\)ߵ(\')ǰϷб( \'\\\\xyz\'  \'a\\\'b\')';
$strMIME_transformation_options = '任ѡ';
$strMIME_transformation = '任';
$strMIMETypesForTable = 'MIME ͱ';
$strMIME_without = 'бӡ MIME ûеı任';
$strModifications = '޸Ѿ档';
$strModify = '޸';
$strModifyIndexTopic = '޸';
$strMoveTable = 'ƶ(ݿ<b>.</b>)';
$strMoveTableOK = ' %s Ѿƶ %s';
$strMoveTableSameNames = '޷ƶΪͬƣ';
$strMultilingual = '';
$strMySQLCharset = 'MySQL ַ';
$strMySQLConnectionCollation = 'MySQL У';
$strMySQLSaid = 'MySQL أ';
$strMySQLShowProcess = 'ʾ';
$strMySQLShowStatus = 'ʾ MySQL Ϣ';
$strMySQLShowVars = 'ʾ MySQL ϵͳ';

$strName = '';
$strNext = 'һ';
$strNo = '';
$strNoActivity = ' %s  ϵķǻ״̬³ʱµ¼';
$strNoDatabases = 'ݿ';
$strNoDatabasesSelected = 'ûѡݿ⡣';
$strNoDescription = '';
$strNoDropDatabases = 'ѾáDROP DATABASE䡣';
$strNoExplain = 'Թ SQL';
$strNoFrames = 'phpMyAdmin ʺ֧<b></b>ʹá';
$strNoIndexPartsDefined = 'ûж֣';
$strNoIndex = 'ûѶ';
$strNoModification = '޸';
$strNone = '';
$strNoOptions = 'ָʽѡ';
$strNoPassword = '';
$strNoPermission = 'վļ %s';
$strNoPhp = ' PHP ';
$strNoPrivileges = 'Ȩ';
$strNoRights = 'û㹻Ȩڴ˳֣';
$strNoRowsSelected = 'δѡ';
$strNoSpace = 'û㹻Ŀռ䱣ļ %s';
$strNoTablesFound = 'ݿûб';
$strNoThemeSupport = '֧⣬Լļ %s.';
$strNotNumber = 'ⲻһ֣';
$strNotOK = '';
$strNotSet = '<b>%s</b> Ҳδ %s 趨';
$strNoUsersFound = 'Ҳû';
$strNoValidateSQL = 'ԹУ SQL';
$strNull = 'Null';
$strNumSearchResultsInTable = '%s ƥ - ڱ <i>%s</i> ';
$strNumSearchResultsTotal = '<b>ܼƣ</b> <i>%s</i> ƥ';
$strNumTables = '';

$strOK = 'ȷ';
$strOperations = '';
$strOperator = 'Ա';
$strOptimizeTable = 'Ż';
$strOr = '';
$strOverhead = '';
$strOverwriteExisting = 'ļ';

$strPageNumber = 'ҳţ';
$strPaperSize = 'ֽŴС';
$strPartialText = '';
$strPassword = '';
$strPasswordChanged = '%s ѳɹġ';
$strPasswordEmpty = 'ǿյģ';
$strPasswordHashing = 'ϣ';
$strPasswordNotSame = '벢ͬ';
$strPdfDbSchema = '%sݿ -  %s ҳ';
$strPdfInvalidTblName = '%sڣ';
$strPdfNoTables = 'ûб';
$strPerHour = 'ÿСʱ';
$strPerMinute = 'ÿ';
$strPerSecond = 'ÿ';
$strPersian = '˹';
$strPhoneBook = '绰';
$strPHP40203 = 'ʹ PHP 汾 4.2.3ð汾һ˫ַֽ(mbstring)ش PHP 汨 19404phpMyAdmin ʹ汾 PHP';
$strPhp = ' PHP ';
$strPHPVersion = 'PHP 汾';
$strPmaDocumentation = 'phpMyAdmin ĵ';
$strPmaUriError = 'ļ趨 <tt>$cfg[\'PmaAbsoluteUri\']</tt> ָ';
$strPolish = '';
$strPortrait = '';
$strPos1 = 'ʼ';
$strPrevious = 'ǰһ';
$strPrimary = '';
$strPrimaryKeyHasBeenDropped = 'ѱɾ';
$strPrimaryKeyName = 'ƱΪ PRIMARY';
$strPrimaryKeyWarning = '(PRIMARY<b></b>ƣ<b>Ψһ</b>)';
$strPrint = 'ӡ';
$strPrintView = 'ӡԤ';
$strPrintViewFull = 'ӡԤ (ȫʾ)';
$strPrivDescAllPrivileges = 'Ȩ޳Ȩ (GRANT)';
$strPrivDescAlter = '޸бĽṹ';
$strPrivDescCreateDb = 'ݿͱ';
$strPrivDescCreateTbl = '±';
$strPrivDescCreateTmpTable = 'ʱ';
$strPrivDescDelete = 'ɾݡ';
$strPrivDescDropDb = 'ɾݿͱ';
$strPrivDescDropTbl = 'ɾ';
$strPrivDescExecute = 'д洢̣ڴ˰汾 MySQL Ч';
$strPrivDescFile = 'ļеԼݵļ';
$strPrivDescGrant = 'ûȨޣȨޱ';
$strPrivDescIndex = 'ɾ';
$strPrivDescInsert = '滻ݡ';
$strPrivDescLockTables = 'סǰı';
$strPrivDescMaxConnections = 'ûÿСʱ򿪵';
$strPrivDescMaxQuestions = 'ûÿСʱɷ͵Ĳѯ';
$strPrivDescMaxUpdates = 'ûÿСʱִеĽκαݿ';
$strPrivDescProcess3 = 'ɱûĽ̡';
$strPrivDescProcess4 = '鿴беѯ';
$strPrivDescReferences = 'ڴ˰汾 MySQL Ч';
$strPrivDescReload = 'òˢ·Ļ档';
$strPrivDescReplClient = 'ûȨѯʸ/';
$strPrivDescReplSlave = 'ظ衣';
$strPrivDescSelect = 'ȡݡ';
$strPrivDescShowDb = 'ݿб';
$strPrivDescShutdown = 'رշ';
$strPrivDescSuper = 'ڴﵽĿʱԽӣڴȫֱɱû߳ĹǱġ';
$strPrivDescUpdate = 'ݡ';
$strPrivDescUsage = 'Ȩޡ';
$strPrivileges = 'Ȩ';
$strPrivilegesReloaded = 'ȨѾɹ롣';
$strProcesses = '';
$strProcesslist = 'б';
$strPutColNames = 'ֶƷ';

$strQBE = 'ѯ';
$strQBEDel = 'ɾ';
$strQBEIns = '';
$strQueryFrame = 'ѯ';
$strQueryOnDb = 'ݿ <b>%s</b> ִ SQL 䣺';
$strQuerySQLHistory = 'SQL ʷ';
$strQueryStatistics = '<b>ѯͳ</b>Դ󣬷յ %s βѯ';
$strQueryTime = 'ѯ %01.4f ';
$strQueryType = 'ѯʽ';
$strQueryWindowLock = 'Ӵ⸲Ǵ˲ѯ';

$strReceived = 'յ';
$strRecords = '¼';
$strReferentialIntegrity = 'ԣ';
$strRefresh = 'ˢ';
$strRelationalSchema = 'ϵ';
$strRelationNotWorking = 'ʹӱĶδҪԭ뵥%s˴%s';
$strRelations = 'ϵ';
$strRelationsForTable = 'Ĺ';
$strRelationView = 'ϵ鿴';
$strReloadingThePrivileges = 'Ȩ';
$strRemoveSelectedUsers = 'ɾѡû';
$strRenameDatabaseOK = 'ݿ %s ѾΪ %s';
$strRenameTableOK = ' %s Ѿĳ %s';
$strRenameTable = 'Ϊ';
$strRepairTable = '޸';
$strReplaceNULLBy = ' NULL 滻Ϊ';
$strReplaceTable = 'ôļ滻';
$strReset = '';
$strResourceLimits = 'Դ';
$strReType = '';
$strRevoke = 'ջ';
$strRevokeAndDeleteDescr = 'ûȻӵ USAGE ȨޣֱȨء';
$strRevokeAndDelete = 'ջûмȨޣȻɾû';
$strRevokeMessage = 'ջ %s Ȩ';
$strRomanian = '';
$strRowLength = 'г';
$strRows = '';
$strRowsFrom = 'Уʼ';
$strRowSize = ' дС ';
$strRowsModeFlippedHorizontal = 'ˮƽ(ת)';
$strRowsModeHorizontal = 'ˮƽ';
$strRowsModeOptions = ' %s ģʽʾ %s Ԫظ';
$strRowsModeVertical = 'ֱ';
$strRowsStatistic = 'ͳ';
$strRunning = ' %s';
$strRunQuery = 'ύѯ';
$strRunSQLQuery = 'ݿ %s  SQL ѯ';
$strRussian = '';

$strSave = '';
$strSaveOnServer = 'ڷ %s Ŀ¼';
$strScaleFactorSmall = '̫С޷һҳʾ';
$strSearch = '';
$strSearchFormTitle = 'ݿ';
$strSearchInTables = '±';
$strSearchNeedle = 'ҵֵֻ(ͨ%)';
$strSearchOption1 = 'һ';
$strSearchOption2 = 'е';
$strSearchOption3 = 'ȷ';
$strSearchOption4 = 'ʽ';
$strSearchResultsFor = '<i>%s</i> %s';
$strSearchType = 'ң';
$strSecretRequired = 'ļҪܵĶ(blowfish_secret)';
$strSelectADb = 'ѡݿ';
$strSelectAll = 'ȫѡ';
$strSelectBinaryLog = 'ѡ鿴־';
$strSelectFields = 'ѡһֶΣ';
$strSelectNumRows = 'ѯ';
$strSelectTables = 'ѡ';
$strSend = 'Ϊļ';
$strSent = 'ͳ';
$strServer = '';
$strServerChoice = 'ѡ';
$strServerNotResponding = 'ûӦ';
$strServerStatusUptime = ' MySQL Ѿ %sʱΪ %s';
$strServerStatus = 'Ϣ';
$strServerTabVariables = '';
$strServerTrafficNotes = '<b></b>Щʾ˴ MySQL ͳơ';
$strServerVars = '';
$strServerVersion = '汾';
$strSessionValue = 'Ựֵ';
$strSetEnumVal = 'ֶǡenumsetʹµĸʽ룺\'a\',\'b\',\'c\'...<br />Ҫֵ뷴б(\)ߵ(\')ǰϷб( \'\\\\xyz\'  \'a\\\'b\')';
$strShow = 'ʾ';
$strShowAll = 'ȫʾ';
$strShowColor = 'ʾɫ';
$strShowDatadictAs = 'ֵʽ';
$strShowFullQueries = 'ʾѯ';
$strShowGrid = 'ʾ';
$strShowingRecords = 'ʾ';
$strShowPHPInfo = 'ʾ PHP Ϣ';
$strShowTableDimension = 'ʾС';
$strShowTables = 'ʾ';
$strShowThisQuery = ' ڴٴʾ˲ѯ ';
$strSimplifiedChinese = '';
$strSingly = '(һ)';
$strSize = 'С';
$strSlovak = '˹工';
$strSlovenian = '˹';
$strSort = '';
$strSortByKey = '';
$strSpaceUsage = 'ʹÿռ';
$strSpanish = '';
$strSplitWordsWithSpace = 'ÿԿո (" ") ָ';
$strSQLExportType = '';
$strSQLOptions = 'SQL ѡ';
$strSQLParserBugMessage = 'п SQL ĳ档ϸĲѯǷȷǷƥ䡣ܵʧԭϴ˳ıĶݡ MySQL нһĲѯܵĻ»г MySQL ĴܶһİáȻ⣬нִгɹ뽫 SQL ѯĳһ䣬Ȼеһύһ汨棺';
$strSQLParserUserError = ' SQL ѯдܵĻ»г MySQL Ĵܶһİá';
$strSQLQuery = 'SQL ѯ';
$strSQLResult = 'SQL ѯ';
$strSQL = 'SQL'; // should express in english
$strSQPBugInvalidIdentifer = 'Чıʶ';
$strSQPBugUnclosedQuote = 'Ų';
$strSQPBugUnknownPunctuation = 'δ֪ıַ';
$strStatCheckTime = 'ʱ';
$strStatCreateTime = 'ʱ';
$strStatement = '';
$strStatUpdateTime = 'ʱ';
$strStatus = '״̬';
$strStrucCSV = 'CSV ';
$strStrucData = 'ṹ';
$strStrucExcelCSV = 'MS Excel  CSV ʽ';
$strStrucNativeExcel = ' MS Excel ';
$strStrucOnly = 'ֻṹ';
$strStructPropose = '滮ṹ';
$strStructure = 'ṹ';
$strSubmit = 'ύ';
$strSuccess = 'е SQL Ѿɹˡ';
$strSum = 'ܼ';
$strSwedish = '';
$strSwitchToDatabase = 'ѡ񱻸Ƶݿ';
$strSwitchToTable = 'лƵı';

$strTable = ' ';
$strTableComments = 'ע';
$strTableEmpty = 'ǿյģ';
$strTableHasBeenDropped = ' %s ѱɾ';
$strTableHasBeenEmptied = ' %s ѱ';
$strTableHasBeenFlushed = ' %s ѱǿƸ';
$strTableMaintenance = 'ά';
$strTableOfContents = 'Ŀ¼';
$strTableOptions = 'ѡ';
$strTables = '%s ';
$strTableStructure = 'Ľṹ';
$strTakeIt = '϶';
$strTblPrivileges = 'ָȨ';
$strTextAreaLength = ' ڳ<br />ֶο޷༭ ';
$strThai = '̩';
$strTheme = ' / ';
$strThisHost = '';
$strThreadSuccessfullyKilled = '߳ %s ѳɹɱ';
$strTime = 'ʱ';
$strToggleScratchboard = 'лΰ';
$strTotal = 'ܼ';
$strTotalUC = 'ͳ';
$strTraditionalChinese = '';
$strTraditionalSpanish = 'ͳ';
$strTraffic = '';
$strTransformation_application_octetstream__download = 'ֶʾһļӡһѡǶݵ֡ڶѡǱпܰļֶΡ ṩڶѡôһѡΪַ';
$strTransformation_image_jpeg__inline = 'ʾɵͼѡָĿȡ߶(ԭб)';
$strTransformation_image_jpeg__link = 'ʾͼ(ֱӶ)';
$strTransformation_image_png__inline = '鿴 image/jpeg: Ƕ';
$strTransformation_text_plain__external = 'ֻ LINUXⲿͨ׼ֶݡشӦóı׼ĬΪ TidyԺܺõĴӡ HTML 롣Ϊ˰ȫҪֶ༭ļ libraries/transformations/text_plain__external.inc.php ȻеĹߡһѡҪʹõĳţڶѡǳĲڵΪ 1 Ļ htmlspecialchars() ת(ĬΪ 1)ĸΪ 1 ĻݵԪ NOWRAPȫͻ᲻¸ʽֱ(ĬΪ 1)';
$strTransformation_text_plain__formatted = 'ֶεԭʼʽת롣';
$strTransformation_text_plain__imagelink = 'ʾͼӣֶڰļһѡơhttp://domain.com/ǰ׺ڶѡΪλĿȣǸ߶ȡ';
$strTransformation_text_plain__link = 'ʾӣֶڰļһѡơhttp://domain.com/ǰ׺ڶѡӵı(ʾ)';
$strTransformation_text_plain__substr = 'ֻʾַһ֡һѡıʼƫ(ĬΪ 0)ڶѡƫΪյĻʣµıѡǽ׷ӵַ֮(ĬΪ...) .';
$strTruncateQueries = 'ضʾĲѯ';
$strTurkish = '';
$strType = '';

$strUkrainian = 'ڿ';
$strUncheckAll = 'ȫѡ';
$strUnicode = 'Unicode'; //USE ENG
$strUnique = 'Ψһ';
$strUnknown = 'δ֪';
$strUnselectAll = 'ȫѡ';
$strUpdatePrivMessage = 'Ѿ %s Ȩޡ';
$strUpdateProfileMessage = 'ļ¡';
$strUpdateQuery = '²ѯ';
$strUpdComTab = 'οĵйθ Column_comments Ĳ';
$strUpgrade = 'Ӧ %s %s ߸ߡ';
$strUsage = '÷';
$strUseBackquotes = 'ڱֶʹ';
$strUseHostTable = 'ʹ';
$strUserAlreadyExists = 'û %s ڣ';
$strUserEmpty = 'ûǿյģ';
$strUserName = 'û';
$strUserNotFound = 'ѡеûȨޱҲ';
$strUserOverview = 'ûһ';
$strUsersDeleted = 'ѡеûѳɹɾ';
$strUsersHavingAccessToDb = 'ûɷʡ%s';
$strUser = 'û';
$strUseTabKey = ' TAB һֵ,  CTRL+ ƶ';
$strUseTables = 'ʹñ';
$strUseTextField = 'ʹı';
$strUseThisValue = 'ʹôֵ';

$strValidateSQL = 'У SQL';
$strValidatorError = 'SQL У޷ʼǷѾװ%sĵ%sı PHP չ';
$strValue = 'ֵ';
$strVar = '';
$strViewDumpDatabases = '鿴ݿת()';
$strViewDumpDB = '鿴ݿת()';
$strViewDump = '鿴ת()';

$strWebServerUploadDirectoryError = '趨Ŀ¼δʹ';
$strWebServerUploadDirectory = 'վĿ¼';
$strWelcome = 'ӭʹ %s';
$strWestEuropean = 'ŷ';
$strWildcard = 'ͨ';
$strWindowNotFound = 'Ŀڲɸ¡Ѿر˸ڻİȫ˸´ڡ';
$strWithChecked = 'ѡ';
$strWrongUser = 'û/󣬷ʱܾ';

$strXML = 'XML'; //USE ENG

$strYes = '';

$strZeroRemovesTheLimit = 'ע⣺ЩѡΪ 0() ɾơ';
$strZip = 'zip ѹ';

// To translate:
$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
$strAndThen = 'and then';  //to translate

$strBookmarkCreated = 'Bookmark %s created';  //to translate
$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
$strBrowseDistinctValues = 'Browse distinct values';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBusyPages = 'Busy pages';  //to translate

$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
$strCopy = 'Copy';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
$strCSV = 'CSV';  //to translate
$strCSVImportOptions = 'CSV options';  //to translate

$strDataPages = 'Pages containing data';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate

$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strEngines = 'Engines';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strErrorInZipFile = 'Error in ZIP archive:';  //to translate
$strEsperanto = 'Esperanto';  //to translate

$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
$strFileNameTemplateDescriptionServer = 'server name';  //to translate
$strFileNameTemplateDescriptionTable = 'table name';  //to translate
$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
$strFileToImport = 'File to import';  //to translate
$strFlushQueryCache = 'Flush query cache';  //to translate
$strFlushTables = 'Flush (close) all tables';  //to translate
$strFreePages = 'Free pages';  //to translate

$strGenerate = 'Generate';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate

$strHandler = 'Handler';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate

$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
$strImportFormat = 'Format of imported file';  //to translate
$strImport = 'Import';  //to translate
$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
$strInvalidRowNumber = '%d is not valid row number.';  //to translate
$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate

$strJoins = 'Joins';  //to translate

$strKeyCache = 'Key cache';  //to translate

$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strLDI = 'CSV using LOAD DATA';  //to translate
$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
$strLDILocal = 'Use LOCAL keyword';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate

$strMaxConnects = 'max. concurrent connections';  //to translate
$strMaximalQueryLength = 'Maximal length of created query';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMysqlClientVersion = 'MySQL client version';  //to translate

$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
$strNumberOfFields = 'Number of fields';  //to translate

$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate

$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strPartialImport = 'Partial import';  //to translate
$strPDFOptions = 'PDF options';  //to translate
$strPDF = 'PDF';  //to translate
$strPDFReportTitle = 'Report title';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming user accounts.';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
$strProtocolVersion = 'Protocol version';  //to translate

$strQueryCache = 'Query cache';  //to translate

$strReadRequests = 'Read requests';  //to translate
$strReloadPrivileges = 'Reload privileges';  //to translate
$strReplication = 'Replication';  //to translate
$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate

$strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
$strShowingBookmark = 'Showing bookmark';  //to translate
$strShowOpenTables = 'Show open tables';  //to translate
$strShowSlaveHosts = 'Show slave hosts';  //to translate
$strShowSlaveStatus = 'Show slave status';  //to translate
$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
$strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
$strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
$strShowStatusCreated_tmp_filesDescr = 'How many temporary files mysqld has created.';  //to translate
$strShowStatusCreated_tmp_tablesDescr = 'The number of in-memory temporary tables created automatically by the server while executing statements.';  //to translate
$strShowStatusDelayed_errorsDescr = 'The number of rows written with INSERT DELAYED for which some error occurred (probably duplicate key).';  //to translate
$strShowStatusDelayed_insert_threadsDescr = 'The number of INSERT DELAYED handler threads in use. Every different table on which one uses INSERT DELAYED gets its own thread.';  //to translate
$strShowStatusDelayed_writesDescr = 'The number of INSERT DELAYED rows written.';  //to translate
$strShowStatusFlush_commandsDescr  = 'The number of executed FLUSH statements.';  //to translate
$strShowStatusHandler_commitDescr = 'The number of internal COMMIT statements.';  //to translate
$strShowStatusHandler_deleteDescr = 'The number of times a row was deleted from a table.';  //to translate
$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
$strShowStatusHandler_read_firstDescr = 'The number of times the first entry was read from an index. If this is high, it suggests that the server is doing a lot of full index scans; for example, SELECT col1 FROM foo, assuming that col1 is indexed.';  //to translate
$strShowStatusHandler_read_keyDescr = 'The number of requests to read a row based on a key. If this is high, it is a good indication that your queries and tables are properly indexed.';  //to translate
$strShowStatusHandler_read_nextDescr = 'The number of requests to read the next row in key order. This is incremented if you are querying an index column with a range constraint or if you are doing an index scan.';  //to translate
$strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.';  //to translate
$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
$strShowStatusHandler_read_rnd_nextDescr = 'The number of requests to read the next row in the data file. This is high if you are doing a lot of table scans. Generally this suggests that your tables are not properly indexed or that your queries are not written to take advantage of the indexes you have.';  //to translate
$strShowStatusHandler_rollbackDescr = 'The number of internal ROLLBACK statements.';  //to translate
$strShowStatusHandler_updateDescr = 'The number of requests to update a row in a table.';  //to translate
$strShowStatusHandler_writeDescr = 'The number of requests to insert a row in a table.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
$strShowStatusKey_blocks_not_flushedDescr = 'The number of key blocks in the key cache that have changed but haven\'t yet been flushed to disk. It used to be known as Not_flushed_key_blocks.';  //to translate
$strShowStatusKey_blocks_unusedDescr = 'The number of unused blocks in the key cache. You can use this value to determine how much of the key cache is in use.';  //to translate
$strShowStatusKey_blocks_usedDescr = 'The number of used blocks in the key cache. This value is a high-water mark that indicates the maximum number of blocks that have ever been in use at one time.';  //to translate
$strShowStatusKey_read_requestsDescr = 'The number of requests to read a key block from the cache.';  //to translate
$strShowStatusKey_readsDescr = 'The number of physical reads of a key block from disk. If Key_reads is big, then your key_buffer_size value is probably too small. The cache miss rate can be calculated as Key_reads/Key_read_requests.';  //to translate
$strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
$strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
$strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
$strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
$strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
$strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
$strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
$strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
$strShowStatusQcache_insertsDescr = 'The number of queries added to the cache.';  //to translate
$strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been removed from the cache to free up memory for caching new queries. This information can help you tune the query cache size. The query cache uses a least recently used (LRU) strategy to decide which queries to remove from the cache.';  //to translate
$strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
$strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
$strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
$strShowStatusReset = 'Reset';  //to translate
$strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
$strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
$strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
$strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
$strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
$strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
$strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
$strShowStatusSlave_runningDescr = 'This is ON if this server is a slave that is connected to a master.';  //to translate
$strShowStatusSlow_launch_threadsDescr = 'The number of threads that have taken more than slow_launch_time seconds to create.';  //to translate
$strShowStatusSlow_queriesDescr = 'The number of queries that have taken more than long_query_time seconds.';  //to translate
$strShowStatusSort_merge_passesDescr = 'The number of merge passes the sort algorithm has had to do. If this value is large, you should consider increasing the value of the sort_buffer_size system variable.';  //to translate
$strShowStatusSort_rangeDescr = 'The number of sorts that were done with ranges.';  //to translate
$strShowStatusSort_rowsDescr = 'The number of sorted rows.';  //to translate
$strShowStatusSort_scanDescr = 'The number of sorts that were done by scanning the table.';  //to translate
$strShowStatusTable_locks_immediateDescr = 'The number of times that a table lock was acquired immediately.';  //to translate
$strShowStatusTable_locks_waitedDescr = 'The number of times that a table lock could not be acquired immediately and a wait was needed. If this is high, and you have performance problems, you should first optimize your queries, and then either split your table or tables or use replication.';  //to translate
$strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache. The cache hit rate can be calculated as Threads_created/Connections. If this value is red you should raise your thread_cache_size.';  //to translate
$strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
$strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
$strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strSorting = 'Sorting';  //to translate
$strSQLCompatibility = 'SQL compatibility mode';  //to translate
$strSQLImportOptions = 'SQL options';  //to translate
$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate

$strTableAlreadyExists = 'Table %s already exists!';  //to translate
$strTempData = 'Temporary data';  //to translate
$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
$strThemeNotFound = 'Theme %s not found!';  //to translate
$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
$strThreads = 'Threads';  //to translate
$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
$strTransactionCoordinator = 'Transaction coordinator';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data. Optional first parameter specifies how often space will be added (defaults to 2 nibbles).';  //to translate
$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate

$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
$strUsedPhpExtensions = 'Used PHP extensions';  //to translate

$strVersionInformation = 'Version information';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
$strView = 'View';  //to translate

$strWriteRequests = 'Write requests';  //to translate

$strQueryResultsOperations = 'Query results operations';  //to translate
$strAddClause = 'Add %s';  //to translate
$strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
$strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
$strXMLOptions = 'XML options';  //to translate
$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
$strCreateUserDatabase = 'Database for user';  //to translate
$strCreateUserDatabaseNone = 'None';  //to translate
$strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
$strOpenDocumentText = 'Open Document Text';  //to translate
$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
$strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
$strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
$strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
$strInvalidTableName = 'Invalid table name';  //to translate
$strInvalidDatabase = 'Invalid database';  //to translate
$strServers = 'Servers';  //to translate
$strDelimiter = 'Delimiter';  //to translate
$strFunctions = 'Functions';  //to translate
$strProcedures = 'Procedures';  //to translate
$strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
$strFontSize = 'Font size';  //to translate
$strLanguage = 'Language';  //to translate
$strPmaWiki = 'phpMyAdmin wiki';  //to translate
$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
$strDocSQL = 'DocSQL';  //to translate
$strDocSQLOptions = 'DocSQL options';  //to translate
$strTableName = 'Table name';  //to translate
$strTableIsEmpty = 'Table seems to be empty!';  //to translate
$strDbIsEmpty = 'Database seems to be empty!';  //to translate
$strShowingPhp = 'Showing as PHP code';  //to translate
$strShowingSQL = 'Showing SQL query';  //to translate
$strDesigner = 'Designer';  //to translate
$strNumberOfTables = 'Number of tables';  //to translate
$strCreateTable  = 'Create table';  //to translate
$strCreateRelation = 'Create relation';  //to translate
$strSavePosition = 'Save position';  //to translate
$strSelectForeignKey = 'Select Foreign Key';  //to translate
$strHide         = 'Hide';  //to translate
$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
$strReload = 'Reload';  //to translate
$strSmallBigAll = 'Small/Big All';  //to translate
$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
$strMoveMenu = 'Move Menu';  //to translate
$strAngularLinks = 'Angular links';  //to translate
$strDirectLinks = 'Direct links';  //to translate
$strHideShowAll = 'Hide/Show all';  //to translate
$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
$strInternalRelationAdded = 'Internal relation added';  //to translate
$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
$strRelationDeleted = 'Relation deleted';  //to translate
$strToSelectRelation = 'To select relation, click :';  //to translate
$strExportImportToScale = 'Export/Import to scale';  //to translate
$strRecommended = 'recommended';  //to translate
$strToFromPage = 'to/from page';  //to translate
$strSelectReferencedKey = 'Select referenced key';  //to translate
$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
$strHelp = 'Help';  //to translate
$strCancel = 'Cancel';  //to translate
$strDeleteRelation = 'Delete relation';  //to translate
$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
$strStructureForView = 'Structure for view';  //to translate
$strStandInStructureForView = 'Stand-in structure for view';  //to translate
$strToggleSmallBig = 'Toggle small/big';  //to translate
$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
$strErrorRelationExists = 'Error: relation already exists.';  //to translate
$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
$strSnapToGrid = 'Snap to grid';  //to translate
$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
?>
